=======
Session
=======

The Session Class
=================

.. module:: webuntis

.. autoclass:: Session

    .. automethod:: login
    .. automethod:: logout
    .. autoattribute:: config
    .. autoattribute:: cache


Things you can do with the API
==============================

.. class:: Session

    .. automethod:: departments
    .. automethod:: holidays
    .. automethod:: klassen
    .. automethod:: timetable
    .. automethod:: rooms
    .. automethod:: schoolyears
    .. automethod:: statusdata
    .. automethod:: subjects
    .. automethod:: teachers
    .. automethod:: statusdata
    .. automethod:: last_import_time
    .. automethod:: substitutions
    .. automethod:: timegrid_units
    .. automethod:: students
    .. automethod:: exam_types
    .. automethod:: exams
    .. automethod:: timetable_with_absences
    .. automethod:: class_reg_events

